@@ -3,9 +3,6 @@ import urllib
 
 from .models.TestObjectInfo import TestObjectInfo
 
-#Services commands
-from testwizard.commands_services import SendNotificationCommand
-
 class TestObjectBase():
     def __init__(self, session, name, category):
         if session is None:
@@ -49,20 +46,4 @@ class TestObjectBase():
     def throwIfDisposed(self):
         if self.__isDisposed is True:
             print("Cannot access a disposed object")
-            raise Exception("Cannot access a disposed object.")
-
-    def sendNotification(self, errorId, description, priority):
-        self.throwIfDisposed()
-        return SendNotificationCommand(self).execute(errorId, description, priority)
-        
-    def setAttributeOnScreenDisplay(self, attributeType, osdArea,  textColor, backgroundColor, duration):
-        self.throwIfDisposed()
-        return SetAttributeOnScreenDisplayCommand(self).execute(attributeType, osdArea,  textColor, backgroundColor, duration)
-        
-    def setTextOnScreenDisplay(self, osdText, osdArea,  textColor, backgroundColor, duration):
-        self.throwIfDisposed()
-        return SetTextOnScreenDisplayCommand(self).execute(osdText, osdArea,  textColor, backgroundColor, duration)
-        
-    def clearOnScreenDisplay(self, osdArea):
-        self.throwIfDisposed()
-        return ClearOnScreenDisplayCommand(self).execute(osdArea)
\ No newline at end of file
+            raise Exception("Cannot access a disposed object.")        
\ No newline at end of file
